/*
 HMGGEN - Harbour Application Generator source code

 Copyright 2014 Frank Alleman <f.alleman@chello.nl>

 This program is free software; you can redistribute it and/or modify it under 
 the terms of the GNU General Public License as published by the Free Software 
 Foundation; either version 2 of the License, or (at your option) any later 
 version. 

 This program is distributed in the hope that it will be useful, but WITHOUT 
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with 
 this software; see the file COPYING. If not, write to the Free Software 
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA (or 
 visit the web site http://www.gnu.org/).

 As a special exception, you have permission for additional uses of the text 
 contained in this release of HMG.

 The exception is that, if you link the HMG library with other 
 files to produce an executable, this does not by itself cause the resulting 
 executable to be covered by the GNU General Public License.
 Your use of that executable is in no way restricted on account of linking the 
 HMG library code into it.

 Parts of this project are based upon:

	HMG - Harbour Windows GUI library source code
	Copyright 2002-2010 Roberto Lopez <mail.box.hmg@gmail.com>
	http://sites.google.com/site/hmgweb/

	"Harbour GUI framework for Win32"
 	Copyright 2001 Alexander S.Kresin <alex@belacy.belgorod.su>
 	Copyright 2001 Antonio Linares <alinares@fivetech.com>
	www - http://www.harbour-project.org

	"Harbour Project"
	Copyright 1999-2008, http://www.harbour-project.org/

	"WHAT32"
	Copyright 2002 AJ Wos <andrwos@aust1.net> 

	"HWGUI"
  	Copyright 2001-2008 Alexander S.Kresin <alex@belacy.belgorod.su>

*/

#include <hmg.ch>
#include "hbclass.ch"

declare window HG0000

function HG0000_process_OnDblClick()
   local item1
   if HG0000.grid_1_1.value > 0
      item1 := HG0000.grid_1_1.Item(HG0000.grid_1_1.value)
      for n := 1 to len(application:processes)
         if application:processes[n]:id = item1[2]
            HG0000_activities_Update(application:processes[n])
            exit
         endif
      next
   endif
return(nil)

function HG0000_activity_OnDblClick()
   local item1, m, n, bFound := .F.
   if HG0000.grid_1_2.value > 0
      item1 := HG0000.grid_1_2.Item(HG0000.grid_1_2.value)
      for n := 1 to len(application:processes)
         for m := 1 to len(application:processes[n]:activityDefinitions)
            if application:processes[n]:activityDefinitions[m]:id = item1[7]
               HG0000_next_activities_Update(application:processes[n]:activityDefinitions[m])
               bFound := .T.
               exit
            endif
         next
         if bFound
            exit
         endif
      next      
   endif
return(nil)

function HG0000_class_OnDblClick()
   local item1, n
   if HG0000.grid_2_1.value > 0
      item1 := HG0000.grid_2_1.Item(HG0000.grid_2_1.value)
      for n := 1 to len(application:classes)
         if application:classes[n]:id = item1[2]
            HG0000_properties_Update(application:classes[n])
            HG0000_rules_Update(application:classes[n])
            exit
         endif
      next
   endif
return(nil)

function HG0000_activities_Update(process)
   local d
   HG0000.grid_1_2.DeleteAllItems
   for n := 1 to len(process:activityDefinitions)
      d := process:activityDefinitions[n]
      HG0000.grid_1_2.AddItem({d:nameActivity, d:codeTeam, d:codeRole, d:indicAuto, d:Indic4Eyes, ;
      str(d:numberOfMonthsRecallterm), d:id})
   next
   if len(process:activityDefinitions) > 0
      HG0000.grid_1_2.value := 1
      HG0000_next_activities_Update(process:activityDefinitions[1])
   else   
      HG0000.grid_1_3.DeleteAllItems
   endif
return(nil)

function HG0000_next_activities_Update(activityDefinition)
   local text, na
   HG0000.grid_1_3.DeleteAllItems
   for n := 1 to len(activityDefinition:nextActivities)
      na := activityDefinition:nextActivities[n]
      text := LookupNameActivity(na:idNextActivity)
      HG0000.grid_1_3.AddItem({na:descrStatus, na:descrCondition, text, na:id})
   next
   if len(activityDefinition:nextActivities) > 0
      HG0000.grid_1_3.value := 1
   endif
return(nil)

function HG0000_properties_Update(class)
   local property
   HG0000.grid_2_2.DeleteAllItems
   for n := 1 to len(class:properties)
      property := class:properties[n]
      HG0000.grid_2_2.AddItem({property:nameProperty, property:nameDatabaseFile, property:codeMultiplicity, ;
      property:nameDatabaseField, property:codeType, str(property:valueLength), str(property:valueDecimals), ;
      property:descrValidations, property:id})
   next
   if len(class:properties) > 0
      HG0000.grid_2_2.value := 1
   endif
return(nil)

function HG0000_rules_Update(class)
   HG0000.grid_2_3.DeleteAllItems
   for n := 1 to len(class:rules)
      HG0000.grid_2_3.AddItem({class:rules[n]:descrCondition, class:rules[n]:descrAction, class:rules[n]:id})
   next
   if len(class:rules) > 0
      HG0000.grid_2_3.value := 1
   endif
return(nil)

function LookupNameActivity(nId, oProcess)
   local text := "", process, activityDefinition, n, m, bFound := .F.
   if pcount() = 1
      for n := 1 to len(application:processes)
         process := application:processes[n]
         for m := 1 to len(process:activityDefinitions)
            activityDefinition := process:activityDefinitions[m]
            if activityDefinition:id = nId
               text := activityDefinition:nameActivity
               bFound := .T.
               exit
            endif   
         next
         if bFound
            exit
         endif   
      next   
   else
      for m := 1 to len(oProcess:activityDefinitions)
         activityDefinition := oProcess:activityDefinitions[m]
         if activityDefinition:id = nId
            text := activityDefinition:nameActivity
            exit
         endif   
      next
   endif   
return(text)